@@ -3,7 +3,7 @@
 
 #include <QWidget>
 #include <QFrame>
-// #include <QtDesigner/QDesignerExportWidget>
+#include <QColorDialog>
 
 //===========================================================
 class ColorTestZone : public QWidget
