@@ -51,7 +51,10 @@ void  GribRecord::translateDataType ()
 			)
 				dataType = GRB_TYPE_NOT_DEFINED;
 		}
-		
+		// altitude level (entire atmosphere vs entire atmosphere considered as 1 level)
+		if (levelType == LV_ATMOS_ENT) {
+				levelType = LV_ATMOS_ALL;
+		}
 	}
 	//------------------------
 	// NOAA Waves
@@ -108,6 +111,13 @@ void  GribRecord::translateDataType ()
 		dataCenterModel = FNMOC_WW3_MED;
 	}
 	//----------------------------------------------
+	// SKIRON Model  http://wild-silk.org/en
+	//----------------------------------------------
+	else if (idCenter==7 && idModel==31 && idGrid==255)
+	{
+		dataCenterModel = SKIRON;
+	}
+	//----------------------------------------------
 	// FNMOC WW3
 	//----------------------------------------------
 	else if (idCenter==58 && idModel==110 && idGrid==240)
