@@ -519,7 +519,7 @@ void MapDrawer::draw_MeteoData_Gridded
 		DataCode dtc (GRB_PRESSURE_MSL,LV_MSL,0);
 		addUsedDataCenterModel (dtc, plotter);
 		plotter->complete_listIsolines (&listIsobars, dtc,
-						   84000, 112000, isobarsStep*100);
+						   84000, 112000, isobarsStep*100, proj);
         plotter->draw_listIsolines (listIsobars, pnt,proj);
 	}
 
@@ -528,7 +528,7 @@ void MapDrawer::draw_MeteoData_Gridded
 		DataCode dtc (GRB_GEOPOT_HGT,LV_ISOTHERM0,0);
 		addUsedDataCenterModel (dtc, plotter);
 		plotter->complete_listIsolines (&listIsotherms0, dtc,
-						   0, 15000, isotherms0Step );
+						   0, 15000, isotherms0Step, proj);
         plotter->draw_listIsolines (listIsotherms0, pnt,proj);
 	}
 
@@ -536,7 +536,7 @@ void MapDrawer::draw_MeteoData_Gridded
 		pnt.setPen (geopotentialsPen);
 		plotter->complete_listIsolines (&listGeopotential,
 						   geopotentialData,
-						   geopotentialMin, geopotentialMax, geopotentialStep );
+						   geopotentialMin, geopotentialMax, geopotentialStep, proj);
         plotter->draw_listIsolines (listGeopotential, pnt,proj);
 	}
 	
@@ -545,7 +545,7 @@ void MapDrawer::draw_MeteoData_Gridded
 		DataCode dtc (GRB_TEMP,isothermsAltitude);
 		addUsedDataCenterModel (dtc, plotter);
 		plotter->complete_listIsolines (&listIsotherms, dtc,
-						   -140+273.15, 80+273.15, isotherms_Step);
+						   -140+273.15, 80+273.15, isotherms_Step, proj);
         plotter->draw_listIsolines (listIsotherms, pnt,proj);
 	}
 	
@@ -554,7 +554,7 @@ void MapDrawer::draw_MeteoData_Gridded
 		DataCode dtc (GRB_PRV_THETA_E,linesThetaEAltitude);
 		addUsedDataCenterModel (dtc, plotter);
 		plotter->complete_listIsolines (&listLinesThetaE, dtc,
-						   -80+273.15, 140+273.15, linesThetaE_Step);
+						   -80+273.15, 140+273.15, linesThetaE_Step, proj);
         plotter->draw_listIsolines (listLinesThetaE, pnt,proj);
 	}
 
