@@ -670,9 +670,9 @@ void MeteoTableWidget::addLine_Temperature(const Altitude &alt, uchar type, int
 		time_t date = *it;
 		if (type == GRB_PRV_THETA_E) {
 			int P = alt.levelValue;	// 925 850 700 600 500 400 300 200
-			double SH = reader->getDateInterpolatedValue (DataCode(GRB_HUMID_SPEC,alt), lon,lat,date);
+			double RH = reader->getDateInterpolatedValue (DataCode(GRB_HUMID_REL,alt), lon,lat,date);
 			double T = reader->getDateInterpolatedValue (DataCode(GRB_TEMP,alt), lon,lat,date);
-			v = DataRecordAbstract::computeThetaE (T,P,SH);
+			v = Therm::thetaEfromHR (T, P, RH);
 		}
 		else
 			v = reader->getDateInterpolatedValue (DataCode(type,alt), lon,lat, date);
